@@ -1,5 +1,5 @@
 /*
- * $Id: template.c,v 1.7.2.17 2009/02/06 05:30:05 tomcollins Exp $
+ * $Id: template.c,v 1.7.2.17 2009-02-06 05:30:05 tomcollins Exp $
  * Copyright (C) 1999-2004 Inter7 Internet Technologies, Inc. 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -47,6 +47,7 @@
 #include "template.h"
 #include "user.h"
 #include "util.h"
+#include "storage.h"
 
 static char dchar[4];
 void check_mailbox_flags(char newchar);
@@ -241,7 +242,19 @@ int send_template_now(char *filename)
               printf ("        </tr>\n");
               printf ("       </table>\n");
               printf ("       <textarea cols=80 rows=40 name=\"message\">");
+
+			  /*
+			     Skip custom headers
+			  */
+
+			  while(1) {
                 fgets(TmpBuf2, sizeof(TmpBuf2), fs);
+				if ((*TmpBuf2 == '\r') || (*TmpBuf2 == '\n'))
+				   break;
+			  }
+
+			  printf("%s", TmpBuf2);
+
               while (fgets(TmpBuf2, sizeof(TmpBuf2), fs)) {
                 printf ("%s", TmpBuf2);
               }
@@ -426,8 +439,8 @@ int send_template_now(char *filename)
           case 'Q':
             vpw = vauth_getpw(ActionUser, Domain);
             if (strncmp(vpw->pw_shell, "NOQUOTA", 2) != 0) {
-              long diskquota = 0;
-              int maxmsg = 0;
+              storage_t diskquota = 0;
+              storage_t maxmsg = 0;
               char path[256];
 
               quota_to_megabytes(qconvert, vpw->pw_shell);
@@ -447,7 +460,7 @@ int send_template_now(char *filename)
                if(AdminType == DOMAIN_ADMIN) 
                   printf("NOQUOTA");
                else
-                  printf(html_text[229]);
+                  printf("%s", html_text[229]);
             }
             break; 
 
@@ -547,8 +560,8 @@ int send_template_now(char *filename)
                * then again, with recent changes, the non-admin shouldn't
                * even get to this page.
                */
-              long diskquota = 0;
-              int maxmsg = 0;
+              storage_t diskquota = 0;
+              storage_t maxmsg = 0;
 	      char path[256];
               vpw = vauth_getpw(Username, Domain);
 
@@ -559,7 +572,7 @@ int send_template_now(char *filename)
               if (strncmp(vpw->pw_shell, "NOQUOTA", 2) != 0) {
                 quota_to_megabytes(qconvert, vpw->pw_shell);
               } else {
-                sprintf(qconvert, html_text[229]); qnote = "";
+                sprintf(qconvert, "%s", html_text[229]); qnote = "";
               }
               printf ("<font size=\"2\" color=\"#000000\"><b>%s:</b><br>%s %s %s",
                 html_text[249], html_text[253], qconvert, qnote);
