@@ -1,5 +1,5 @@
 /* 
- * $Id: user.c,v 1.11.2.21 2009/05/02 19:13:29 tomcollins Exp $
+ * $Id: user.c,v 1.11.2.21 2009-05-02 19:13:29 tomcollins Exp $
  * Copyright (C) 1999-2004 Inter7 Internet Technologies, Inc. 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -170,8 +170,8 @@ int show_user_lines(char *user, char *dom, time_t mytime, char *dir)
               (AdminType==USER_ADMIN && strcmp(pw->pw_name,Username)==0)))) {
         if (AdminType==DOMAIN_ADMIN || 
             (AdminType==USER_ADMIN && strcmp(pw->pw_name,Username)==0)) {
-          long diskquota = 0;
-          int maxmsg = 0;
+          storage_t diskquota = 0;
+          storage_t maxmsg = 0;
 
           /* display account name and user name */
           printf ("<tr bgcolor=%s>", get_color_text("000"));
